@@ -12,8 +12,8 @@ from nltk.tokenize import word_tokenize
 #from text_preprocessor import TextPreProcessor
 from .text_preprocessor import TextPreProcessor
 from conllu import parse_tree
-from utilities import *
-#from .utilities import *
+#from utilities import *
+from .utilities import *
 
 
 #####################################################
