@@ -1,8 +1,8 @@
 import re
 
 from difflib import SequenceMatcher
-from dicts import *
-#from .dicts import *
+#from dicts import *
+from .dicts import *
 import pymorphy2
 
 morph = pymorphy2.MorphAnalyzer()
